@@ -6,10 +6,11 @@ from magicapi import g
 
 from magicapi.Decorators.background_tasks import run_in_background
 
-print("sentry dsn", g.settings.sentry_dsn)
 HAS_SENTRY_DSN = g.settings.sentry_dsn
 if HAS_SENTRY_DSN:
     sentry_sdk.init(
         dsn=g.settings.sentry_dsn,
-        traces_sample_rate=1.0,
+        traces_sample_rate=g.settings.sentry_traces_sample_rate,
+        send_default_pii=True,
+        request_bodies="always",
     )
