@@ -93,9 +93,12 @@ class MagicSettings(BaseSettings):
     company_name: str = None
 
     # for stripe
+    stripe_secret_key: str = None  # usually do this in more custom config
+    """
     stripe_api_key_sandbox: str = None
     stripe_api_key_production: str = None
     stripe_env: Literal["sandbox", "production"] = None
+    """
 
     # for sentry
     sentry_dsn: str = None
